| Title: | Easily Install and Load the EPI R Package Suite |
|---|---|
| Description: | The 'epiverse' package makes it easy to install and load the collection of R packages maintained by the Economic Policy Institute. Loading 'epiverse' attaches all included packages and reports any function conflicts. |
| Authors: | Ben Zipperer [aut, cre], Economic Policy Institute [cph, fnd] |
| Maintainer: | Ben Zipperer <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.2.0 |
| Built: | 2026-05-14 05:03:00 UTC |
| Source: | https://github.com/economic/epiverse |
Lists all function conflicts between epiverse packages and other packages that you have loaded.
epiverse_conflicts(only = NULL)epiverse_conflicts(only = NULL)
only |
Set this to a character vector to restrict to conflicts only with these packages. |
An object of class epiverse_conflicts, invisibly. Printed output
shows which epiverse functions mask functions from other packages.
## Not run: epiverse_conflicts() ## End(Not run)## Not run: epiverse_conflicts() ## End(Not run)
Returns the names of all packages included in epiverse, read from the package DESCRIPTION file at runtime.
epiverse_packages(include_self = TRUE)epiverse_packages(include_self = TRUE)
include_self |
If |
A character vector of package names.
epiverse_packages()epiverse_packages()